{% extends 'aa_forum/base.html' %}

{% load aa_forum_template_variables %}
{% load bootstrap %}
{% load evelinks %}
{% load static %}
{% load i18n %}

{% block page_title %}{% translate 'New Topic » Forum' %}{% endblock %}

{% block aa_forum_header %}
    <br>

    {% include "aa_forum/partials/menu.html" %}
{% endblock %}

{% block aa_forum_body %}
    {% set_template_variable category_slug = board.category.slug %}
    {% set_template_variable board_slug = board.slug %}

    <div class="panel panel-default">
        <div class="panel-heading">
            <div class="panel-title">
                {% translate "Start new topic in" %}
                "<a href="{% url 'aa_forum:forum_board' category_slug board_slug %}">{{ board.name }}</a>"
            </div>
        </div>

        <div class="panel-body">
            <form autocomplete="off" action="{% url "aa_forum:forum_board_new_topic" category_slug board_slug %}" method="post">
                {% csrf_token %}

                {{ form|bootstrap }}

                {% include "aa_forum/partials/form/required_field_hint.html" %}

                <div class="form-group text-right clearfix">
                    <button class="btn btn-primary btn-sm" type="submit">{% translate "Start Topic" %}</button>
                </div>
            </form>
        </div>
    </div>
{% endblock %}

{% block extra_css %}
    <link rel="stylesheet" type="text/css" href="{% static 'aa_forum/css/aa-bootstrap-fix.min.css' %}">
    <link rel="stylesheet" type="text/css" href="{% static 'aa_forum/css/aa-forum.min.css' %}">
{% endblock %}

{% block extra_javascript %}
    <script type="text/javascript" src="{% static "ckeditor/ckeditor-init.js" %}"></script>
    <script type="application/javascript" src="{% static "ckeditor/ckeditor/ckeditor.js" %}"></script>
{% endblock %}
